<?php

namespace App\Http\Controllers;

use App\Interfaces\ICompany;
use App\Traits\RequestTrait;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CompanyController extends Controller
{
    use RequestTrait;

    private $company, $types, $currentTime, $branch;
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(ICompany $company)
    {
        $this->company = $company;

        $this->currentTime = Carbon::now();
    }

    public function index()
    {

        $companies = $this->company->allCompanies();

        return $this->sendResponse($companies->body, 'success');
    }


    public function createCompany(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'client_name' => 'required|string|max:191',
            'sector_id' => 'required|integer',
            'license_id' => 'required|integer',
            'country_id' => 'required|integer',
            'state_id' => 'required|integer',
            'contact' => 'required|numeric',
            'alt_contact' => 'nullable|numeric',
            'email' => 'required|email',
            'alt_email' => 'nullable|email',
            'logo' => 'nullable|image:mimes:jpeg,jpg,png'
        ]);

        if ($validator->fails()) {
            return $this->sendError("Validation Error - {$validator->errors()->first()}",  $validator->errors());
        }


        $data = $this->jsonRequestDataToFormData($request);

        $response = $this->company->createClient($data);

        if ($response->status_code == 200) {
            $this->company->create([
                'client_name' => $response->body->data,
                'client_slug' => $response->body->data
            ]);
        }


        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function findCompany($slug)
    {
        $company = $this->company->fetchCompany($slug);

        return $this->sendResponse($company, 'success');
    }


    public function updateCompany(Request $request, $slug)
    {
        $validator = Validator::make($request->all(), [
            'client_name' => 'required|string|max:191',
            'sector_id' => 'nullable|integer',
            'country_id' => 'nullable|integer',
            'state_id' => 'nullable|integer',
            // 'city_id' => 'required|integer',
            'contact' => 'required|numeric',
            'alt_contact' => 'nullable|numeric',
            // 'email' => 'required|email|unique:clients,email',
            'alt_email' => 'nullable|email',
            'logo' => 'nullable',
            'address' => 'required'
        ]);

        if ($validator->fails()) {
            return $this->sendError("Validation Error - {$validator->errors()->first()}",  $validator->errors());
        }

        $data = $this->jsonRequestDataToFormData($request);

        $response = $this->company->updateClient($data, $slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function enableCompany($company_slug)
    {
        $response =  $this->company->enableCompany($company_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function disableCompany($company_slug)
    {
        $response = $this->company->disableCompany($company_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function branches($company_slug)
    {
        $response = $this->company->companyBranch($company_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function allIcons()
    {
        $response = $this->company->icons();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function clientIcons($client_slug)
    {
        $response = $this->company->clientIcons($client_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function backgrounds()
    {
        $response = $this->company->backgrounds();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function clientbackgrounds($client_slug)
    {
        $response = $this->company->clientBackgrounds($client_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
}
