<?php

namespace App\Http\Controllers;

use Laravel\Lumen\Routing\Controller as BaseController;

class Controller extends BaseController
{

    /**
     * success response method.
     *
     * @return \Illuminate\Http\Response
     */
    public function sendResponse($result, $message)
    {
        $response = [
            'success' => true,
            'status' => 1,
            'data'    => $result,
            'message' => $message,
        ];

        return response()->json($response, 200);
    }

    /**
     * return error response.
     *
     * @return \Illuminate\Http\Response
     */
    public function sendError($error, $errorMessages = [], $code = 400)
    {
        $response = [
            'success' => false,
            'status' => 0,
            'message' => $error,
        ];

        if (!empty($errorMessages)) {
            $response['data'] = $errorMessages;
        }

        return response()->json($response, $code, [], 0);
    }

    protected function sendHttpStatusResponse($body, int $status_code)
    {
        return response()->json($body, $status_code, [], 0);
    }

    protected function sendBadRequestResponse($errors)
    {
        return response()->json([
            "message" => "Invalid user request",
            "errors" => $errors,
            "status" => 0,
            "status_code" => 400,
        ], 400, [], 0);
    }

    protected function sendSuccessResponse($message, $data = [])
    {
        $response = [
            "message" => $message,
            "status" => 1,
            "status_code" => 200,
        ];
        if ($data)
            $response["data"] = $data;

        return response()->json($response);
    }

    protected function sendNotFoundResponse($message, $data = [])
    {
        $response = [
            "message" => $message,
            "status" => 0,
            "status_code" => 404,
        ];
        if (count($data))
            $response["data"] = $data;

        return response()->json($response, 404);
    }

    protected function sendUnAuthorisedResponse($message = "Unauthorised request")
    {
        $response = [
            "message" => $message,
            "status" => 0,
            "status_code" => 401,
        ];
        return response()->json($response, 401);
    }

    protected function sendGenericErrorResponse($message)
    {
        $response = [
            "message" => $message,
            "status" => 0,
            "status_code" => 400,
        ];

        return response()->json($response, 400);
    }

}
