<?php

namespace App\Http\Controllers;

use App\Interfaces\IProgram;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class ProgramController extends Controller
{

    private $program, $currentTime;
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(IProgram $program)
    {
        $this->program = $program;
       
    }

    public function all()
    {
        $programs = $this->program->getItem(['active_flag'=> 1], ['id', 'name', 'program_slug']);

        return $this->sendResponse($programs, 'success');
    }
    
    public function createProgram(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "name" => "required|unique:programs",
            "program_slug" => "required|unique:programs,program_slug",
            "company_id"=> 'required|integer',
            'logo'=> 'nullable|url'
        ]);

        if ($validator->fails()) {
            return $this->sendError('Validation Error- ' . $validator->errors()->first(), $validator->errors());
        }

        $token = Str::random(128);

        $this->program->create([
            "token" => $token,
            "name" => $request->get("name"),
            "program_slug" => $request->get("program_slug"),
            "company_id"=> $request->get('company_id'),
            "logo"=> $request->get('logo') ?? null,
            'created_at'=> $this->currentTime
        ]);

        return $this->sendResponse('', 'Program created successfully');
    }

    public function enableProgram($slug)
    {
        $program = $this->program->findItem(['program_slug'=> $slug]);

        if(is_null($program)){
            return $this->sendError('Invalid Program slug');
        }

        if($program->active_flag == 0){
            $this->program->updateItem(['program_slug'=> $slug], ['active_flag'=>1]);
        }

        $program->active_flag = 1;

        return $this->sendResponse('Program enabled successfully','');
    }

    public function disableProgram($slug)
    {
        $program = $this->program->findItem(['program_slug' => $slug]);

        if (is_null($program)) {
            return $this->sendError('Invalid Program slug');
        }

        if ($program->active_flag == 1) {
            $this->program->updateItem(['program_slug' => $slug], ['active_flag' => 0]);
        }

        $program->active_flag = 1;

        return $this->sendResponse('Program disabled successfully', '');
    }

    public function company_program($id)
    {
        $company = $this->program->findItem(['company_id'=> $id]);

        if(is_null($company)){
            return $this->sendError('Invalid Company id');
        }

        if($company->status == 1){
           $program =  $this->program->selectItems(['company_id'=> $company->id], ['name', 'program_slug', 'logo']);
        }

        return $this->sendResponse($program, '');
    }

    


}
