<?php

namespace App\Http\Controllers;

use App\Interfaces\IPrivilage;
use App\Interfaces\IRole;
use App\Traits\Helpers;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class RoleController extends Controller
{
    use Helpers;

    private $roles, $privilages, $currentTime;
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(IRole $roles, IPrivilage $privilages)
    {
        $this->roles = $roles;
        $this->privilages = $privilages;
        $this->currentTime = Carbon::now();
    }

    public function index()
    {
        $roles = $this->roles->selectItems(['active_flag'=>1],['name','role_slug','active_flag']);

        return $this->sendResponse($roles, 'success');
    }

    public function allRoles()
    {
        $roles = $this->roles->selectAll(['name', 'role_slug', 'active_flag']);

        return $this->sendResponse($roles, 'success');
    }

    public function createRole(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name'=> 'required|unique:roles',
            "role_slug" => "required|unique:roles,role_slug",
           
        ]);

        if($validator->fails()){
            return $this->sendError('Validation Error- ' . $validator->errors()->first(), $validator->errors());
        }

        $this->roles->create([
            'name'=> $request->get('name'),
            'role_slug'=> $request->get('role_slug'),
           // 'company_id' => $request->company->id
        ]);

        return $this->sendResponse($this->roles->new_insert(['id', 'name', 'role_slug']), 'Role created successfully');
    }

    public function updateRole(Request $request, $slug)
    {

      
        $validator = Validator::make($request->all(), [
            'name'=> 'required',
        ]);

        if ($validator->fails()) {
            return $this->sendError('Validation Error- ' . $validator->errors()->first(), $validator->errors());
        }

        $role = $this->roles->findItem(['role_slug'=> $slug]);

        if(is_null($role)){
            return $this->sendError('Invalid role slug');
        }

        if($role->active_flag == 0){
            return $this->sendError('Role is not active');
        }

        $this->roles->updateItem(['role_slug'=> $role->role_slug], [
            'name'=> $request->get('name'),
            'updated_at'=> $this->currentTime
        ]);

        $role->name = $request->get('name');
        $role->updated_at = $this->currentTime;

        return $this->sendResponse($role, 'Role updated successfully');
        
    }

    public function enableRole(Request $request)
    {
        $role = $this->roles->findItem(['role_slug'=> $request->segment(4)]);

        if(is_null($role)){
            return $this->sendError('Invalid role slug');
        }

        if($role->active_flag ==  0){
            $this->roles->updateItem(['role_slug'=> $role->role_slug], [
                'active_flag'=> 1,
                'updated_at'=> $this->currentTime
            ]);
        }

        $role->active_flag = 1;

        return $this->sendResponse($role, 'Role enabled successfully');


    }

    public function disableRole(Request $request)
    {

         $role = $this->roles->findItem(['role_slug'=> $request->segment(4)]);

        if(is_null($role)){
            return $this->sendError('Invalid role slug');
        }

        if($role->active_flag ==  1){
            $this->roles->updateItem(['role_slug'=> $role->role_slug], [
                'active_flag'=> 0,
                'updated_at'=> $this->currentTime
            ]);
        }

        $role->active_flag = 0;

        return $this->sendResponse($role, 'Role disabled successfully');
    }


    public function rolePermissions(Request $request)
    {
        $role = $this->roles->findItem(['role_slug'=> $request->segment(4)]);

        if(is_null($role)){
            return $this->sendError('Invalid role slug');
        }

        if($role->active_flag == 0){
            return $this->sendError('The role is not active');
        }

        $claims = $this->privilages->getUserClaims($role->id);

        return $this->sendResponse($claims, 'Success');
    }

    
}
