<?php

namespace App\Http\Controllers\Survey;

use App\Http\Controllers\Controller;
use App\Interfaces\Survey\IResponseGroup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ResponseGroupController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */

     public $response_group;

    public function __construct(IResponseGroup $response_group)
    {
        $this->response_group = $response_group;
    }


    public function getResponseGroups()
    {
        $response = $this->response_group->responseGroups();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function getClientResponseGroups(Request $request, $client_slug)
    {
        $active = null;
        if($request->query('active') == "true"){
            $active = 'active';
        }

        $response = $this->response_group->clientResponseGroups($client_slug, $active);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function createClientResponseGroup(Request $request, $client_slug)
    {
        $validate = Validator::make($request->all(), [
            'response_group' => "required|string",
            'has_images' => "required|integer|min:0|max:1",
            'options' => "nullable|array",
            // 'options.*' => "required|array",
            // 'options.*.name' => "required",
            // 'options.*.require_comment'=>"nullable|boolean",
            // 'options.*.icon_url' => "string|required_if:has_images,1",
        ]);

        if($validate->fails()){
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->createClientResponseGroup($request->all(), $client_slug);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }


    public function updateClientResponseGroup(Request $request, $client_slug, $group_id)
    {
        $validate = Validator::make($request->all(), [
            'response_group'=> 'required',
            'has_images'=> 'required|integer',
            'options' => "nullable|array"
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->updateClientResponseGroup($request->all(),$client_slug, $group_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function disableClientResponseGroup(Request $request, $client_slug, $group_id)
    {
        $response = $this->response_group->disableClientResponseGroup($client_slug, $group_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function enableClientResponseGroup(Request $request, $client_slug, $group_id)
    {
        $response = $this->response_group->enableClientResponseGroup($client_slug, $group_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function getClientResponseGroupOptions($client_slug, $group_id)
    {
       $response = $this->response_group->clientResponseGroupOptions($client_slug, $group_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }


    public function getClientResponseOptions(Request $request, $client_slug)
    {
        $active = null;
        if($request->query('active') == "true"){
            $active = 'true';
        }

       $response = $this->response_group->clientResponseOptions($client_slug, $active);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }


    public function getClientResponseOptionsWithIcons($client_slug)
    {
       $response = $this->response_group->clientResponseOptionsWithIcons($client_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }


    public function createClientResponseOption(Request $request, $client_slug)
    {
        $validate = Validator::make($request->all(), [
            'option' => "required|string",
            // 'allow_image' => "required|integer|min:0|max:1",
            'icon' => "nullable|string",
        ]);

        if($validate->fails()){
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->createClientResponseOptions($request->all(), $client_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function updateClientResponseOption(Request $request, $client_slug, $option_id)
    {
        $validate = Validator::make($request->all(), [
            'option'=> 'required|string',
            'icon' => "nullable|string"
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->updateClientResponseOption($request->all(),$client_slug, $option_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function disableClientResponseOption(Request $request, $client_slug, $option_id)
    {
        $response = $this->response_group->disableClientResponseOption($client_slug, $option_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function enableClientResponseOption(Request $request, $client_slug, $option_id)
    {
        $response = $this->response_group->enableClientResponseOption($client_slug, $option_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function addResponseGroupOptions(Request $request, $client_slug, $group_id)
    {
        $validate = Validator::make($request->all(), [
            'option'=> 'required',
            'icon_url'=> 'nullable'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->addClientResponseGroupOption($request->all(), $client_slug, $group_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function updateClientResponseGroupOption(Request $request, $client_slug, $group_id, $option_id)
    {
        $validate = Validator::make($request->all(), [
            'option' => 'required',
            'icon_url' => 'nullable'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->response_group->updateClientResponseGroupOption($request->all(), $client_slug, $group_id, $option_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }


    public function deleteClientResponseGroupOption($client_slug, $group_id, $option_id)
    {
        $response = $this->response_group->deleteClientResponseGroupOption($client_slug, $group_id, $option_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
}
