<?php

namespace App\Http\Controllers\Survey;

use App\Http\Controllers\Controller;
use App\Interfaces\Survey\ISurvey;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class SurveyController extends Controller
{

    public $survey;

    public function __construct(ISurvey $survey)
    {
        $this->survey = $survey;
    }

    public function index()
    {
        $response = $this->survey->getSurveys();
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function clientSurvey($client_slug)
    {
        $response = $this->survey->clientSurveys($client_slug);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function getSurvey($client_slug, $survey_id)
    {
        $response = $this->survey->getSurvey($client_slug, $survey_id);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function createclientSurvey(Request $request, $client_slug)
    {
        $validate = Validator::make($request->all(), [
            'title'=> 'required|string',
            'description'=> 'required|string'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->survey->createClientSurvey($request->all(), $client_slug);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function updateclientSurvey(Request $request, $client_slug, $survey_id)
    {
        $validate = Validator::make($request->all(), [
            'title' => 'required|string',
            'description' => 'required|string'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->survey->updateClientSurvey($request->all(), $client_slug, $survey_id);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function disableclientSurvey($client_slug, $survey_id)
    {
        $response = $this->survey->disableClientSurvey($client_slug, $survey_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function enableclientSurvey($client_slug, $survey_id)
    {
        $response = $this->survey->enableClientSurvey($client_slug, $survey_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function ResponseType()
    {
        $response = $this->survey->getResponseType();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
}
