<?php

namespace App\Repo;

use App\Interfaces\IBranch;
use Illuminate\Support\Facades\DB;

class BranchRepo extends BaseRepo implements IBranch
{

    public function __construct($table_name = "branches")
    {
        parent::__construct($table_name);
        $this->table_name = $table_name;
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');
    }


    public function userBranch(int $user_id)
    {
        return DB::table('user_branches')
                    ->leftJoin('branches', 'user_branches.branch_id', '=', 'branches.id')
                    ->where('user_branches.user_id', '=', $user_id)
                    ->select('branches.*', 'user_branches.toggle_status')
                    ->get();
    }


    public function addbranch(array $data)
    {
        return $this->makeRequest->postAsJson("branch/create", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function update_branch(array $data, $branch_slug)
    {
        return $this->makeRequest->postAsJson("branch/update/{$branch_slug}", $data, [
            'client-Key' => $this->token
        ]);
    }

    public function get_branch($branch_slug)
    {
        return $this->makeRequest->getAsJson("branch/find/{$branch_slug}", [
            'client-Key' => $this->token
        ]);
    }

    public function disable_branch($branch_slug)
    {

        return $this->makeRequest->postAsJson("branch/disable/{$branch_slug}", [],[
            'client-Key' => $this->token
        ]);
    }

    public function enable_branch($branch_slug)
    {

        return $this->makeRequest->postAsJson("branch/enable/{$branch_slug}",[], [
            'client-Key' => $this->token
        ]);
    }

    public function active_branch($client_slug)
    {

        return $this->makeRequest->getAsJson("branch/{$client_slug}", [
            'client-Key' => $this->token
        ]);

    }

    public function get_branch_token($branch_slug)
    {
        return $this->makeRequest->getAsJson("branch/{$branch_slug}/branch-token", [
            'client-Key' => $this->token
        ]);
    }

    public function passwordChange($data)
    {
        return $this->makeRequest->postAsJson("branch/change-password", $data, [
             'client-Key' => $this->token
        ]);
    }

    public function branchReport($client_slug,$branch_id, $survey_id, $data)
    {
       
        return $this->makeRequest->postAsJson("{$client_slug}/survey/{$survey_id}/responses/{$branch_id}", $data, [
            'client-Key' => $this->token
        ]);
    }

    public function repondentReport($client_slug, $survey_id, $branch_slug, $data)
    {
       
        return $this->makeRequest->postAsJson("{$client_slug}/survey/{$survey_id}/report/{$branch_slug}",$data, [
            'client-Key' => $this->token
        ]);
    }

    public function adminSummary($client_slug, $survey_id, $data)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/survey/{$survey_id}/responses", $data, [
            'client-Key' => $this->token
        ]);

    }

    public function adminReport($client_slug, $survey_id, $data)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/survey/{$survey_id}/report", $data, [
            'client-Key' => $this->token
        ]);
    }

    

}
