<?php

namespace App\Repo;

use App\Interfaces\IPrivilage;
use App\Models\RolePrivilege;
use Illuminate\Support\Facades\DB;

class PrivilageRepo extends BaseRepo implements IPrivilage
{

    public function __construct($table_name="privileges")
    {
        parent::__construct($table_name);
    }
    public function assignPrivilegesToRoles(object $permission, object $role)
    {
        RolePrivilege::updateOrCreate(
            ["role_id" => $role->id, "privilege_id" => $permission->id],
            [
                "create" => $permission->create ?? 0, "read" => $permission->read ?? 0,
                "update" => $permission->update ?? 0, "delete" => $permission->delete ?? 0
            ]
        );
    }

    public function getUserClaims(int $role_id)
    {
        return DB::table("roles_privileges AS rp")
            ->join("privileges AS p", function ($query) {
                $query->on("p.id", "=", "rp.privilege_id")
                    ->where(["p.active_flag" => 1]);
            })->select(
                "p.name",
                "rp.privilege_id",
                DB::raw("CASE WHEN p.create=1 AND rp.create=1 THEN 1 END AS 'create',
                            CASE WHEN p.read=1 AND rp.read=1 THEN 1 END AS 'read',
                            CASE WHEN p.update=1 AND rp.update=1 THEN 1 END AS 'update',
                            CASE WHEN p.delete=1 AND rp.read=1 THEN 1 END AS 'delete'    
                        ")
            )
            ->where("rp.role_id", $role_id)
            ->get();
    }


    public function getUserCompany(int $user_id)
    {
        return DB::table("branches AS b")
            ->join("users_branches AS ub", function ($query) {
                $query->on("b.id", "=", "up.branch_id")
                    ->where(["b.active_flag" => 1]);
            })->select(
                "b.branch_name",
                
                "p.program_slug",
                "p.id",
                "up.active_flag"
            )
            ->where("up.user_id", $user_id)
            ->get();
    }

    public function getUserActiveProgram(int $user_id)
    {
        return DB::table("programs AS p")
            ->join("users_programs AS up", function ($query) {
                $query->on("p.id", "=", "up.program_id")
                    ->where(["p.active_flag" => 1, "up.active_flag" => 1]);
            })->select(
                "p.name",
                "p.image",
                "p.program_slug",
                "p.id",
                "up.active_flag"
            )
            ->where("up.user_id", $user_id)
            ->first();
    }

    public function getCompanyBranches(int $company_id)
    {
        return DB::table('branches')
                    ->leftJoin('countries', 'branches.country_id', '=', 'countries.id')
                    ->leftJoin('states', 'branches.state_id', '=', 'states.id')
                    ->leftJoin('cities', 'branches.city_id', '=', 'cities.id')
                    ->where('branches.status', '=', 1)
                    ->select("branches.id", 'branches.branch_name', 'branches.slug', 'branches.branch_code', 'branches.branch_address','branches.active_flag', 'countries.id', 'countries.country_name', 'countries.country_code', 'states.state_name', 'cities.city_name')
                    ->get();
                    
    }
}