<?php

namespace App\Repo\SurveyRepo;

use App\Interfaces\Survey\IQuestion;
use App\Repo\BaseRepo;
use App\Repo\MakeRequest;

class QuestionRepo extends BaseRepo implements IQuestion
{

    public $token;

    public $makeRequest;

    public function __construct($table_name = "surveys")
    {
        parent::__construct($table_name);
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');
    }

    public function surveyQuestions(string $client_slug, int $survey_id)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/surveys/{$survey_id}/questions", [
            'client-Key' => $this->token
        ]);
    }

    public function createSurveyQuestion(array $data, string $client_slug, int $survey_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/questions", $data, [
             'client-Key' => $this->token
        ]);
    }

    public function updateSurveyQuestion(array $data, string $client_slug, int $survey_id, int $question_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/questions/{$question_id}/update", $data, [
            'client-Key' => $this->token
        ]);
    }

    public function disableSurveyQuestion(string $client_slug, int $survey_id, int $question_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/questions/{$question_id}/disable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function enableSurveyQuestion(string $client_slug, int $survey_id, int $question_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/questions/{$question_id}/enable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function deleteSurveyQuestion(string $client_slug, int $survey_id, int $question_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/questions/{$question_id}/delete", [], [
            'client-Key' => $this->token
        ]);
    }


}

