<?php

namespace App\Repo\SurveyRepo;

use App\Interfaces\Survey\IResponseGroup;
use App\Repo\BaseRepo;
use App\Repo\MakeRequest;


class ResponseGroupRepo extends BaseRepo implements IResponseGroup
{

    public $token, $apiKey;

    public $makeRequest;

    public function __construct($table_name = "response")
    {
        parent::__construct($table_name);
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');

    }


    public function responseGroups()
    {
        return $this->makeRequest->getAsJson("response_groups", [
            'client-Key' => $this->token
        ]);
    }

    public function clientResponseGroups(string $client_slug, String $active = null)
    {
        if($active == "true"){
            $active = '?active=true';
        }
        else{
            $active = '';
        }

        // $active = $active == null ? '' : '/' . $active;
        return $this->makeRequest->getAsJson("{$client_slug}/response_groups{$active}", [
            'client-Key' => $this->token
        ]);
    }

    public function createClientResponseGroup(array $data, string $client_slug)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function updateClientResponseGroup(array $data, string $client_slug, int $group_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/update", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function disableClientResponseGroup(string $client_slug, int $group_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/disable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function enableClientResponseGroup(string $client_slug, int $group_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/enable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function clientResponseGroupOptions(string $client_slug, int $group_id)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/response_groups/{$group_id}/options", [
            'client-Key' => $this->token
        ]);
    }

    public function clientResponseOptions(string $client_slug, String $active = null)
    {
        if($active == "true"){
            $active = '?active=true';
        }
        else {
            $active = '';
        }

        return $this->makeRequest->getAsJson("{$client_slug}/response_options{$active}", [
            'client-Key' => $this->token
        ]);
    }


    public function createClientResponseOptions(array $data, string $client_slug)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_options", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function updateClientResponseOption(array $data, string $client_slug, int $option_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_options/{$option_id}/update", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function disableClientResponseOption(string $client_slug, $option_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_options/{$option_id}/disable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function enableClientResponseOption(string $client_slug, $option_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_options/{$option_id}/enable", [], [
            'client-Key' => $this->token
        ]);
    }


    public function clientResponseOptionsWithIcons(string $client_slug)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/response_options/icons", [
            'client-Key' => $this->token
        ]);
    }


    public function addClientResponseGroupOption(array $data, string $client_slug, int $group_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/options", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function updateClientResponseGroupOption(array $data, string $client_slug, int $group_id, int $option_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/options/{$option_id}/update", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function deleteClientResponseGroupOption(string $client_slug, int $group_id, int $option_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/response_groups/{$group_id}/options/{$option_id}/delete", [], [
            'client-Key' => $this->token
        ]);
    }


}
