<?php

namespace App\Repo\SurveyRepo;

use App\Interfaces\Survey\ISurvey;
use App\Repo\BaseRepo;
use App\Repo\MakeRequest;


class SurveyRepo extends BaseRepo implements ISurvey
{
    public $token;

    public $makeRequest;


    public function __construct($table_name = "surveys")
    {
        parent::__construct($table_name);
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');
    }

    public function getSurveys()
    {
        return $this->makeRequest->getAsJson("surveys/all", [
            'client-Key' => $this->token
        ]);
    }

    public function clientSurveys(string $client_slug)
    {
        
        return $this->makeRequest->getAsJson("{$client_slug}/surveys", [
            'client-Key' => $this->token
        ]);
    }

    public function getSurvey(string $client_slug, Int $survey_id)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/surveys/{$survey_id}", [
            'client-Key' => $this->token
        ]);
    }

    public function createClientSurvey(array $data, string $client_slug)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys", $data, [
            'client-Key' => $this->token
        ]);
    }
    public function updateClientSurvey(array $data, string $client_slug, int $survey_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}", $data, [
            'client-Key' => $this->token
        ]);
    }
    public function enableClientSurvey(string $client_slug, int $survey_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/enable", [], [
            'client-Key' => $this->token
        ]);
    }
    public function disableClientSurvey(string $client_slug, int $survey_id)
    {
        return $this->makeRequest->postAsJson("{$client_slug}/surveys/{$survey_id}/disable", [], [
            'client-Key' => $this->token
        ]);
    }

    public function getResponseType()
    {
        return $this->makeRequest->getAsJson('response_types', [
            'client-Key' => $this->token
        ]);
    }
}
