<?php

namespace App\Repo;

use App\Interfaces\IUser;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use App\Repo\MakeRequest;

class UserRepo extends BaseRepo implements IUser
{

    public $token, $apiKey;

    public $makeRequest;

    public function __construct($table_name="users")
    {
        parent::__construct($table_name);
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');
        $this->apiKey  = env('APIKEY');
    }

    public function listUsers($client_id)
    {
        return DB::table("users AS u")
                    ->leftJoin('roles As r', 'u.role_id', '=', 'r.id')
                    ->where('u.client_id', '=',$client_id)
                    ->select(
                        "u.id",
                        "u.first_name",
                        "u.last_name",
                        "u.email",
                        "u.phone_number",
                        "terms_agreed_on",
                        "r.name AS role",
                        "u.last_login_date",
                        "u.approved_by",
                        "u.approved_on",
                        "u.active_flag"
                    )
                    ->orderByDesc('id')
                    ->get();
    }

    public function createUser(array $user_details, string $password, int $role_id, int $client_id)
    {

        $user = new User();
        $user->fill($user_details);
        $user->password = Hash::make($password);
        $user->role_id = $role_id;
        $user->client_id = $client_id;
        $user->active_flag = 1;

        

        $super_admin = DB::table('roles')->where('role_slug', 'super-admin')->first();
        $branches = DB::table('branches')->get();

        if($role_id == $super_admin->id){
            $user->super_user = 1;
        }else{
            $user->super_user = 0;
        }
        if($user->save()){

            if($role_id == $super_admin->id){
                foreach ($branches as $branch) {
                    DB::table('user_branches')->insert([
                        'user_id' => $user->id,
                        'branch_id' => $branch->id,
                        'created_at' => Carbon::now(),
                        'toggle_status' => 0
                    ]);
                }

           
            }else{
                foreach ($user_details['branches'] as $branch) {

                    $branch_id = DB::table('branches')->where('branch_slug', $branch)->value('id');

                    DB::table('user_branches')->insert([
                        'user_id' => $user->id,
                        'branch_id' => $branch_id,
                        'created_at' => Carbon::now(),
                        'toggle_status' => 0
                    ]);
                }
            }

            $userbranches = DB::table('user_branches')->where('user_id', $user->id)->first();
            DB::table('user_branches')->where('id', $userbranches->id)->update([
                'toggle_status' => 1
            ]);
            

        }

        return $user;

    }


    public function toggleSwitcher($user_id, $branch_id)
    {

        DB::beginTransaction();

        try {
            DB::table('user_branches')->where('user_id', $user_id)->update(['toggle_status' => 0]);
            DB::table('user_branches')->where('user_id', $user_id)->where('branch_id', $branch_id)->update(['toggle_status'=> 1]);
            DB::commit();
        } catch (\Exception $ex) {
           DB::rollBack();
           return (object)[
                'status'=> 0,
                'message'=> $ex->getMessage()
           ];
        }

        return (object)[
            'status'=> 1,
            'message'=> true
        ];
    }

    public function sendEmail($email, $content_type, $variables = [], $attachment = [])
    {

        return $this->makeRequest->postAsFormData("send-email", [
            'email' =>  $email,
            'type' => $content_type,
            'variables' => $variables,
            'attachment' => $attachment
        ], [
            'client-Key'=> $this->token
        ]);
    }

    public function getuser(int $id)
    {
        return DB::table('users as u')
                    ->leftJoin('roles as r', 'r.id','=', 'u.role_id')
                    ->where('u.id', $id)
                    ->select('u.id', 'u.first_name','u.last_name','u.email','u.phone_number','u.last_login_date','r.name')
                    ->first();
    }

    public function userbranches(int $id)
    {
        return DB::table('user_branches as ub')
                    ->leftJoin('branches as b', 'b.id','=','ub.branch_id')
                    ->where('ub.user_id', $id)
                    ->select('b.id','b.branch_name','b.branch_code', 'b.branch_slug', 'ub.toggle_status')
                    ->get();
    }

    public function AddbranchtoSuper($branch_id, $users)
    {
        foreach ($users as $user) {

            DB::table('user_branches')->insert([
                'user_id'=> $user->id,
                'branch_id'=> $branch_id
            ]);
        }
        return true;
    }
}
