<?php

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It is a breeze. Simply tell Lumen the URIs it should respond to
| and give it the Closure to call when that URI is requested.
|
*/

$router->get('/', function () use ($router) {
    return $router->app->version();
});

$router->group(["prefix"=> "api/v1"], function()use($router)
{
    $router->post('login', 'AuthController@login');
    $router->post('check-token', 'AuthController@checkToken');

    //$router->get('survey/{client_slug}/client-survey', 'Survey\SurveyController@clientSurvey');

     //$router->get("users/menus/{id}", "PrivilegeController@getUserMenu");


    $router->group(['middleware'=> 'auth'], function() use($router){
        $router->post('password-change', 'BranchController@changePassword');

        $router->group(['prefix' => '{company_slug}/users', 'middleware' => 'check-slug'], function () use ($router) {
            //Route for users
            $router->get('/', 'UserController@index');
            $router->post('/create', "UserController@createUser");
            $router->post('{id}/update', 'UserController@updateUser');
            $router->post("{id}/enable", "UserController@enableUser");
            $router->post("{id}/disable", "UserController@disableUser");
            $router->get('{id}', "UserController@getUser");
            $router->get('{id}/branches', 'UserController@userBranches');
            $router->post('{id}/remove-branches', 'UserController@removeBranches');
        });

        $router->group(['prefix' => 'programs'], function () use ($router) {
            $router->get('/', 'ProgramController@all');
            // $router->post('/create-program', 'ProgramController@createProgram');
            // $router->get('/enable-program/{slug}', 'ProgramController@enableProgram');
            // $router->get('/disable-program/{slug}', 'ProgramController@disableProgram');
        });

        $router->group(['prefix' => 'branch'], function () use ($router) {

            $router->get('/user', 'BranchController@userBranches');
            $router->get('/{client_slug}', 'BranchController@activeBranch');
            $router->post('/create', 'BranchController@createBranch');
            $router->get('/{branch_slug}/find', 'BranchController@findBranch');
            $router->post('/{branch_slug}/update', 'BranchController@updateBranch');
            $router->post('/{branch_slug}/disable', 'BranchController@disableBranch');
            $router->post('/{branch_slug}/enable', 'BranchController@enableBranch');
            $router->get('/{branch_slug}/branch-token', 'BranchController@branch_token');
            $router->post('{client_slug}/survey/{survey_id}/reports/{branch_slug}', 'BranchController@BranchSurveyReport');
            $router->post('{client_slug}/survey/{survey_id}/respondent/{branch_slug}', 'BranchController@RepondentReports');

            $router->post('{client_slug}/survey/{survey_id}/admin/summary', 'BranchController@adminSummary');
            $router->post('{client_slug}/survey/{survey_id}/admin/report', 'BranchController@adminReport');
        });

        $router->group(['prefix' => 'branches'], function () use ($router) {
            $router->get('/', 'BranchController@all');
        });

        $router->group(['prefix' => 'company'], function () use ($router) {
            $router->get('/', 'CompanyController@index');
            // $router->post('/create-company', 'CompanyController@createCompany');
            // $router->post('/update-company', 'CompanyController@updateCompany');
            // $router->get('/get-company/{company_slug}', 'CompanyController@getCompany');
            // $router->get('/disable-company/{company_slug}', 'CompanyController@disableCompany');
            // $router->get('/enable-company/{company_slug}', 'CompanyController@enableCompany');
        });

        $router->get("users/menus", "PrivilegeController@getUserMenu");
        $router->post('users/forgot-password', 'UserController@forgotPassword');
        $router->post('users/password-reset', 'UserController@passwordReset');
        $router->post('users/change-password', 'UserController@changePassword');

        $router->group(['prefix' => 'roles'], function () use ($router) {
            //Route for roles
            $router->get('/', 'RoleController@index');
            $router->get('/all-roles', 'RoleController@allRoles');
            $router->get("/{slug}/permissions", "RoleController@rolePermissions");
            $router->post('/create', 'RoleController@createRole');
            $router->post('/{slug}', 'RoleController@updateRole');
            $router->post('/{slug}/enable', 'RoleController@enableRole');
            $router->post('/{slug}/disable', 'RoleController@disableRole');
        });

        $router->group(['prefix' => 'privileges'], function () use ($router) {

            $router->get('/', 'PrivilegeController@index');
            $router->get('all-privileges', 'PrivilegeController@allPrivileges');
            $router->post('create', 'PrivilegeController@createPrivilege');
            // $router->post('update-privilege/{id}', 'PrivilegeController@updatePrivilege');
            // $router->get('disable-privilege/{id}', 'PrivilegeController@disablePrivilege');
            // $router->get('enable-privilege/{id}', 'PrivilegeController@enablePrivilege');
            $router->post('assign', 'PrivilegeController@assignPrivileges');
        });

        $router->group(['prefix' => 'clients'], function () use ($router) {

            $router->get('/', 'CompanyController@index');
            $router->post('create-client', 'CompanyController@createCompany');
            $router->get('find/{slug}', 'CompanyController@findCompany');
            $router->post('update/{slug}', 'CompanyController@updateCompany');
            $router->post('disable/{company_slug}', 'CompanyController@disableCompany');
            $router->post('enable/{company_slug}', 'CompanyController@enableCompany');
            $router->get('branches/{company_slug}', 'CompanyController@branches');
            $router->get('icons', 'CompanyController@allIcons');
            $router->get('{client_slug}/icons', 'CompanyController@clientIcons');
            $router->get('{client_slug}/backgrounds', 'CompanyController@clientbackgrounds');
        });
        $router->get('background', 'CompanyController@backgrounds');

        $router->group(['prefix' => 'parameters'], function () use ($router) {

            $router->get('client-parameters', 'PortalParameterController@createClient');
            $router->get('states/{country_id}', 'PortalParameterController@countryStates');
        });

        $router->group(['prefix' => 'survey'], function () use ($router) {

            /***************************** Survey Types CRUD ****************/

            $router->get('type/active', 'Survey\TypeController@activeTypes');
            $router->get('type', 'Survey\TypeController@Types');
            $router->post('type/create', 'Survey\TypeController@createType');
            $router->post('type/update/{id}', 'Survey\TypeController@updateType');
            $router->post('type/disable/{id}', 'Survey\TypeController@disable_type');
            $router->post('type/enable/{id}', 'Survey\TypeController@enable_type');


            /***************************** Survey Response Groups CRUD *********/
            $router->get('response-group', 'Survey\ResponseGroupController@getResponseGroups');
            $router->get('client-response-group/{client_slug}', 'Survey\ResponseGroupController@getClientResponseGroups');
            $router->post('client-response-group/{client_slug}/disable/{group_id}', 'Survey\ResponseGroupController@disableClientResponseGroup');
            $router->post('client-response-group/{client_slug}/enable/{group_id}', 'Survey\ResponseGroupController@enableClientResponseGroup');
            $router->post('client-response-group/{client_slug}', 'Survey\ResponseGroupController@createClientResponseGroup');
            $router->post('update/{client_slug}/response-group/{group_id}', 'Survey\ResponseGroupController@updateClientResponseGroup');


            $router->get('client-response-option/{client_slug}', 'Survey\ResponseGroupController@getClientResponseOptions');
            $router->get('client-response-option/{client_slug}/icons', 'Survey\ResponseGroupController@getClientResponseOptionsWithIcons');
            $router->post('client-response-option/{client_slug}', 'Survey\ResponseGroupController@createClientResponseOption');
            $router->post('client-response-option/{client_slug}/disable/{option_id}', 'Survey\ResponseGroupController@disableClientResponseOption');
            $router->post('client-response-option/{client_slug}/enable/{option_id}', 'Survey\ResponseGroupController@enableClientResponseOption');
            $router->post('update/{client_slug}/response-option/{option_id}', 'Survey\ResponseGroupController@updateClientResponseOption');

            $router->get('get-group-options/{client_slug}/group/{group_id}/options', 'Survey\ResponseGroupController@getClientResponseGroupOptions');
            $router->post('add/{client_slug}/group/{group_id}/option', 'Survey\ResponseGroupController@addResponseGroupOptions');
            $router->post('update/{client_slug}/group/{group_id}/option/{option_id}', 'Survey\ResponseGroupController@updateClientResponseGroupOption');
            $router->post('delete/{client_slug}/group/{group_id}/option/{option_id}', 'Survey\ResponseGroupController@deleteClientResponseGroupOption');


            /****************************** Survey ************/
            $router->get('/', 'Survey\SurveyController@index');
            $router->get('{client_slug}/client-survey', 'Survey\SurveyController@clientSurvey');
            $router->get('{client_slug}/client-survey/{survey_id}', 'Survey\SurveyController@getSurvey');
            $router->post('{client_slug}/create-client-survey', 'Survey\SurveyController@createclientSurvey');
            $router->post('{client_slug}/update-client-survey/{survey_id}', 'Survey\SurveyController@updateclientSurvey');
            $router->post('{client_slug}/disable-client-survey/{survey_id}', 'Survey\SurveyController@disableclientSurvey');
            $router->post('{client_slug}/enable-client-survey/{survey_id}', 'Survey\SurveyController@enableclientSurvey');

            $router->get('response-types', 'Survey\SurveyController@ResponseType');


            /****************************** Survey Question ********/

            $router->get('{client_slug}/survey/{survey_id}/question/', 'Survey\QuestionController@surveyQuestions');
            $router->post('{client_slug}/survey/{survey_id}/question/create', 'Survey\QuestionController@createSurveyQuestion');
            $router->post('{client_slug}/survey/{survey_id}/question/{question_id}/update', 'Survey\QuestionController@updateSurveyQuestion');
            $router->post('{client_slug}/survey/{survey_id}/question/{quesstion_id}/disable', 'Survey\QuestionController@disableSurveyQuestion');
            $router->post('{client_slug}/survey/{survey_id}/question/{question_id}/enable', 'Survey\QuestionController@enableSurveyQuestion');
        });

        $router->group(['prefix' => 'sector'], function () use ($router) {

            $router->get('/', 'SectorController@sectors');
            $router->post('/create', 'SectorController@create');
            $router->get('/find/{id}', 'SectorController@find');
            $router->post('/update/{id}', 'SectorController@update');
            $router->post('disable/{id}', 'SectorController@disable_sector');
            $router->post('/enable/{id}', 'SectorController@enable_sector');
        });

        $router->group(['prefix' => 'license'], function () use ($router) {

            $router->get('/', 'LicenseController@index');
            $router->get('/find/{id}', 'LicenseController@getLicense');
            $router->post('/create', 'LicenseController@create');
            $router->post('/update/{id}', 'LicenseController@update');
            $router->post('/disable/{id}', 'LicenseController@disable');
            $router->post('enable/{id}', 'LicenseController@enable');
            $router->post('renewal', 'LicenseController@Renewal');
            $router->get('running/clients', 'LicenseController@Runninglicense');
            $router->get('expired/clients', 'LicenseController@Expiredlicense');
            $router->get('{client_slug}/history', 'LicenseController@LicenseHistory');
        });

        $router->group(['prefix' => '{client_slug}/dashboard'], function () use ($router) {

            $router->get('{branch_slug}/data', [
                "middleware" => "branch-check",
                "uses" => "DashboardController@dashboardData"
            ]);

            $router->get('graph', [
                "middleware" => "branch-check",
                "uses" => "DashboardController@graphData"
            ]);

            $router->get('{user_id}/change-branch/{branch_id}', [
                "middleware" => "branch-check",
                "uses" => "UserController@ToggleBranch"
            ]);
        });

    });

});
